csep.utils.basic\_types.AdaptiveHistogram
=========================================

.. currentmodule:: csep.utils.basic_types

.. autoclass:: AdaptiveHistogram

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AdaptiveHistogram.__init__
      ~AdaptiveHistogram.add
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AdaptiveHistogram.rec_dh
   
   